/**
 * Copyright @ 2000 Peter Robach (pr@webapp.de) und Lars Rwekamp (Lars@openKnowlege.de)
 * 
 * Source is only for non commercial and coaching usage.
 * 
 * Not Warranty to use it.
 */

package de.ix.jspTutorial.model;
import java.util.*;
import java.io.*;
import java.net.URL;
import javax.servlet.ServletContext;

/**
 * Liste der Pizza fr den Pizza Services
 * Die Pizza werden aus einer Properties Datei einmalig in den
 * ServletContext geladen.
 *
 * @author Peter Rossbach (<a href="mailto://pr@webapp.de">pr@webapp.de</a>), Lars Rwekamp ( <a href="mailto://lars.roewekamp@openKnowledge.de">lars.roewekamp@openKnowledge.de</a>)
 * @version $Id:$
 */
public class PizzaList {
   private TreeMap pizzas;

   /**
    * Leere Liste von Pizzen
    *
    *
    * @see
    */
   public PizzaList() {
      this.pizzas = new TreeMap();
   }

   /**
    * Initialisiern mit Testpizzen
    *
    *
    * @param pizzas Testpizzen
    *
    * @see
    */
   public PizzaList(TreeMap pizzas) {
      this.pizzas = pizzas;
   }

   /**
    * Hole bestimmte Pizza
    *
    *
    * @param key Bestellnummer der Pizza
    *
    * @return Schlssel der Pizza
    *
    * @see
    */
   public Pizza getPizza(Long key) {
      return (Pizza) pizzas.get(key);
   } 

   /**
    * Hole alle Pizzen
    *
    *
    * @return
    *
    * @see
    */
   public TreeMap getPizzas() {
      return pizzas;
   } 

   /**
    * Lese die Liste der Properties aus der Datei <i>/WEB-INF/config/pizza.properties"</i>
    *
    *
    * @param aApplication ServletContext
    *
    * @see javax.servlet.ServletContext
    */
   public void readList(ServletContext aApplication) {
      readList(aApplication.getResourceAsStream("/WEB-INF/config/pizza.properties"));
   } 

   /**
    * Lese die Liste aus einem Eingabestrom.
    * Format der Datei:
    * <xmp>
    * pizza.count=2
    *
    * pizza.id_0.id=0
    * pizza.id_0.size=klein (15 cm)
    * pizza.id_0.name=Napoli
    * pizza.id_0.basePrice=5.95
    *
    * pizza.id_1.id=1
    * pizza.id_1.size=mittel (22 cm)
    * pizza.id_1.name=Napoli
    * pizza.id_1.basePrice=7.95
    *
    * pizza.id_2.id=2
    * pizza.id_2.size=riesig (35 cm)
    * pizza.id_2.name=Napoli
    * pizza.id_2.basePrice=9.95
    *
    * </xmp>
    * @param aResourceStream der Eingabe Strom
    *
    * @see
    */
   public void readList(InputStream aResourceStream) {
      pizzas = new TreeMap();
      try {
         Properties props = new Properties();

         props.load(aResourceStream);
         Integer pizzaCount = new Integer(props.getProperty("pizza.count"));

         for (int i = 0; i < pizzaCount.intValue(); i++) {
            Long   pizzaId = new Long(props.getProperty("pizza.id_" + i 
                                                        + ".id"));
            String pizzaName = props.getProperty("pizza.id_" + i + ".name");
            String pizzaSize = props.getProperty("pizza.id_" + i + ".size");
            Double basePrice = new Double(props.getProperty("pizza.id_" + i 
                    + ".basePrice"));

            pizzas.put(pizzaId, 
                       new Pizza(pizzaId.longValue(), pizzaName, pizzaSize, 
                                 basePrice.doubleValue()));
         } 
      } catch (Exception e) {
         throw new RuntimeException("Unable to read resource to get data source" 
                                    + e);
      } 
   } 

   /**
    * zeige die Liste der Pizzen
    *
    *
    * @return Liste der Pizzen
    *
    * @see
    */
   public String toString() {
      StringBuffer outStr = new StringBuffer();
      Set    entrySet = pizzas.entrySet();

      outStr.append("[") ;
      for (Iterator iter = entrySet.iterator(); iter.hasNext(); ) {
         Map.Entry entry = (Map.Entry) iter.next();

         outStr.append(((Pizza) entry.getValue()).toString()) ;
         if(iter.hasNext())
         		outStr.append(",\n");
      } 
      outStr.append("]") ;
      return outStr.toString();
   } 
}


//
// History
//
// $Log:$
//
//